Page of results (Please note that if the page parameter exceeds 200, the function returns error)
sort
Ordering of the results, the available options are the following:
- 0: sort by relevance
- 1: recently added contracts first
- 2: recently added contracts last
- 3: the cheapest contracts first
- 4: the most expensive contracts first
- 5: recently concluded contracts first
- 6: recently concluded contracts last
- 7: the most defective contracts first
- 8: sort by purchaser
- 9: sort by supplier
Value
list containing 3 elements:
- Total: Total number of datasets available (integer)
- Page: Page of the result (integer)
- Results: Data.frame with data concerning the datasets