Sorting of results, the available options are the following:
- 0: order by relevance
- 1: order by the date of signature, the most recent first
- 2: order by the date of signature, the most recent last
- 3: order by the size of the subsidy, the largest first
- 4: order by the size of the subsidy, the largest last
- 5: order by ICO in a descending order
- 6: order by ICO in an ascending order